<?php

	define( 'PB_ELEMENTOR_WIDGETS_DIR', get_stylesheet_directory() . '/inc/elementor/widgets' );
	define( 'PB_ELEMENTOR_URL', get_stylesheet_directory() . '/inc/elementor' );
	require_once PB_ELEMENTOR_URL.'/queries.php';
	require_once PB_ELEMENTOR_URL.'/elementor-helper.php';

	/**
	 * Implements the compatibility for the Elementor plugin in Accesspress Parallax theme.
	 *
	 * @package    Accesspress Themes
	 * @subpackage Accesspress Parallax
	 * @since      version 2.0.1
	 */

	/**
	 * Load the Accesspress Parallax Elementor widgets file and registers it
	 */
	if ( ! function_exists( 'parallax_blog_elementor_widgets_registered' ) ) :

		/**
		 * Load and register the required Elementor widgets file
		 *
		 * @param $widgets_manager
		 *
		 * @since version 2.0.1
		 */
		function parallax_blog_elementor_widgets_registered( $widgets_manager ) {

			// Require the files
			require PB_ELEMENTOR_WIDGETS_DIR . '/slider.php';
			require PB_ELEMENTOR_WIDGETS_DIR . '/blog-section.php';

			// Register the widgets
			$widgets_manager->register_widget_type( new \Elementor\Parallax_Slider_Elementor_Section() );
			$widgets_manager->register_widget_type( new \Elementor\Parallax_Blog_Elementor_Section() );

			
		}

	endif;

	add_action( 'elementor/widgets/widgets_registered', 'parallax_blog_elementor_widgets_registered' );

	if ( ! function_exists( 'parallax_blog_elementor_category' ) ) :

		/**
		 * Add the Elementor category for use in Accesspress Parallax widgets
		 *
		 * @since version 2.0.1
		 */
		function parallax_blog_elementor_category() {

			// Register widget block category for Elementor section
			\Elementor\Plugin::instance()->elements_manager->add_category( 'parallax-blog-widget-blocks', array(
				'title' => esc_html__( ' Parallax Blog Blocks', 'accesspress-parallax' ),
			), 1 );
		}

	endif;

	add_action( 'elementor/init', 'parallax_blog_elementor_category' );



	if ( ! function_exists( 'parallax_blog_elementor_enqueue_scripts' ) ) :

		function parallax_blog_elementor_enqueue_scripts() {
			// Enqueue the main Elementor CSS file for use with Elementor
			wp_enqueue_script( 'accesspress-parallax-elementor', get_stylesheet_directory_uri() . '/inc/elementor/assets/js/ap-elementor.js'  );
		}

	endif;

	add_action( 'elementor/frontend/before_enqueue_scripts', 'parallax_blog_elementor_enqueue_scripts' );
