<?php
/**
 *
 * @package parallax_blog
 */
 if(!function_exists('parallax_blog_recent_post_widget')){
add_action('widgets_init', 'parallax_blog_recent_post_widget');

function parallax_blog_recent_post_widget() {
    register_widget('parallax_blog_recent_post');
}
}
if(!class_exists('parallax_blog_recent_post')){
class parallax_blog_recent_post extends WP_Widget {
    /**
     * Register widget with WordPress.
     */
    public function __construct() {
        parent::__construct(
            'parallax_blog_recent_post', esc_html__('Parallax Blog: Recent Post', 'parallax-blog'), array(
            'description' => esc_html__('Recent Posts', 'parallax-blog')
                )
        );
    }

    /**
     * Helper function that holds widget fields
     * Array is used in update and form functions
     */
    private function widget_fields() {
        $parallax_blog_cat_list = parallax_blog_wid_post_categories();
        $fields = array(
            'parallax_blog_recent_post_title' => array(
                'parallax_blog_widgets_name' => 'parallax_blog_recent_post_title',
                'parallax_blog_widgets_title' => esc_html__('Title', 'parallax-blog'),
                'parallax_blog_widgets_field_type' => 'text',
            ),
            'parallax_blog_recent_post_cat' => array(
                'parallax_blog_widgets_name' => 'parallax_blog_recent_post_cat',
                'parallax_blog_widgets_title' => esc_html__('Recent Post Category', 'parallax-blog'),
                'parallax_blog_widgets_field_type' => 'select',
                'parallax_blog_widgets_field_options' => $parallax_blog_cat_list,
            ),
            'parallax_blog_recent_post_per_page' => array(
                'parallax_blog_widgets_name' => 'parallax_blog_recent_post_per_page',
                'parallax_blog_widgets_title' => esc_html__('Posts Per Page', 'parallax-blog'),
                'parallax_blog_widgets_field_type' => 'number',
            ),
        );

        return $fields;
    }

    /**
     * Front-end display of widget.
     *
     * @see WP_Widget::widget()
     *
     * @param array $args     Widget arguments.
     * @param array $instance Saved values from database.
     */
    public function widget($args, $instance) {
        extract($args);
        $parallax_blog_recent_post_title = isset($instance['parallax_blog_recent_post_title']) ? $instance['parallax_blog_recent_post_title'] : '';
        $parallax_blog_recent_post_cat = isset($instance['parallax_blog_recent_post_cat']) ? $instance['parallax_blog_recent_post_cat'] : '';
        $parallax_blog_recent_post_per_page = isset($instance['parallax_blog_recent_post_per_page']) ? $instance['parallax_blog_recent_post_per_page'] : '-1';
        echo wp_kses_post($before_widget);
            if($parallax_blog_recent_post_title || $parallax_blog_recent_post_cat){
                if($parallax_blog_recent_post_title){
                    ?>
                        <h2 class="widget-title"><?php echo esc_html($parallax_blog_recent_post_title); ?></h2>
                    <?php
                }
                $parallax_blog_recent_post_args = array(
                        'post_type' => 'post',
                        'order' => 'DESC',
                        'posts_per_page' => $parallax_blog_recent_post_per_page,
                        'post_status' => 'publish',
                        'cat' => $parallax_blog_recent_post_cat
                    );
                $parallax_blog_recent_post_query = new WP_Query($parallax_blog_recent_post_args);
                if($parallax_blog_recent_post_query->have_posts()):
                    ?>
                    <div class="recent-post-widget">
                        <?php
                        while($parallax_blog_recent_post_query->have_posts()):
                            $parallax_blog_recent_post_query->the_post();
                            $parallax_blog_recent_post_image = wp_get_attachment_image_src(get_post_thumbnail_id(),'pb-post-image');
                            $parallax_blog_recent_post_image_url = $parallax_blog_recent_post_image[0];
                            if($parallax_blog_recent_post_image_url || get_the_title()){
                                ?>
                                    <div class="recent-posts-content">
                                        <?php if($parallax_blog_recent_post_image_url){ ?><div class="image-recent-post">
                                            <a href="<?php echo esc_url( get_permalink() ); ?>"><img src="<?php echo esc_url( $parallax_blog_recent_post_image_url); ?>" alt="<?php echo esc_attr( get_the_title() ); ?>"></a> </div><?php } ?>
                                        <div class="date-title-recent-post">
                                            <?php if(get_the_title()){ ?><span class="recent-post-title"><a href="<?php the_permalink(); ?>"><?php echo esc_html(wp_trim_words(get_the_title(),'10','...')); ?></a></span><?php } ?>
                                            <div class="re-date">
                                                <span class="pb-post-date"><?php echo esc_html(get_the_date()); ?></span>
                                            </div>
                                        </div>

                                    </div>
                                <?php
                            }
                        endwhile;
                        wp_reset_postdata();
                        ?>
                    </div>
                    <?php
                endif;
            }
        echo wp_kses_post($after_widget);
    }

    public function update($new_instance, $old_instance) {
        $instance = $old_instance;

        $widget_fields = $this->widget_fields();

        // Loop through fields
        foreach ($widget_fields as $widget_field) {

            extract($widget_field);

            // Use helper function to get updated field values
            $instance[$parallax_blog_widgets_name] = parallax_blog_widgets_updated_field_value($widget_field, $new_instance[$parallax_blog_widgets_name]);
        }

        return $instance;
    }

    /**
     * Back-end widget form.
     *
     * @see WP_Widget::form()
     *
     * @param   array $instance Previously saved values from database.
     *
     * @uses    parallax_blog_widgets_show_widget_field()      defined in widget-fields.php
     */
    public function form($instance) {
        $widget_fields = $this->widget_fields();

        // Loop through fields
        foreach ($widget_fields as $widget_field) {

            // Make array elements available as variables
            extract($widget_field);
            $parallax_blog_widgets_field_value = !empty($instance[$parallax_blog_widgets_name]) ? esc_html($instance[$parallax_blog_widgets_name]) : '';
            parallax_blog_widgets_show_widget_field($this, $widget_field, $parallax_blog_widgets_field_value);
        }
    }
}
}